%define _name KeePass

Name:           keepass
Version:        2.35
Release:        %mkrel 1
License:        GPLv2+
Summary:        Password Manager
Group:          File tools
Url:            http://keepass.info/
Source:         http://sourceforge.net/projects/keepass/files/KeePass%202.x/%{version}/KeePass-%{version}-Source.zip
Source1:        http://downloads.sourceforge.net/keepass/KeePass-%{version}-French-b.zip
# Upstream does not include a .desktop file, etc..
Patch0:         keepass-desktop-integration.patch
Patch3:         keepass-appdata.patch
# Move XSL files to /usr/share/keepass:
Patch1:         keepass-fix-XSL-search-path.patch
# Locate locally-installed help files:
Patch2:         keepass-enable-local-help.patch
Requires:       xdotool
Requires:       pkgconfig(libgdiplus)
BuildRequires:  unzip
BuildRequires:  monodevelop
BuildRequires:  xdotool-devel
BuildRequires:  xsel
BuildRequires:  pkgconfig(libgdiplus)
BuildRequires:  x11-server-xvfb
BuildRequires:  archmage
BuildArch:      noarch

%description
KeePass is a free open source password manager, which helps you to manage your
passwords in a secure way. You can put all your passwords in one database,
which is locked with one master key or a key file. So you only have to remember
one single master password or select the key file to unlock the whole database.
The databases are encrypted using the best and most secure encryption
algorithms currently known (AES and Twofish).

%prep
%autosetup -p1 -c 

unzip %{SOURCE1}

# Work around BOM-handling bug
# (https://bugzilla.redhat.com/show_bug.cgi?id=1317084):
sed -i '1s/^﻿//' KeePass/KeePass.csproj

%build
( cd Build && sh PrepMonoDev.sh )
find . -name "*.sln" -print -exec sed -i 's/Format Version 10.00/Format Version 11.00/g' {} \;
find . -name "*.csproj" -print -exec sed -i 's#ToolsVersion="3.5"#ToolsVersion="4.0"#g; s#<TargetFrameworkVersion>.*</TargetFrameworkVersion>##g; s#<PropertyGroup>#<PropertyGroup><TargetFrameworkVersion>v4.5</TargetFrameworkVersion>#g' {} \;
xbuild /target:KeePass /property:Configuration=Release
for subdir in Images_App_HighRes Images_Client_16 Images_Client_HighRes; do
    xvfb-run -a mono Build/KeePass/Release/KeePass.exe -d:`pwd`/Ext/$subdir --makexspfile `pwd`/KeePass/Resources/Data/$subdir.bin
done
xbuild /target:KeePass /property:Configuration=Release
%{__python2} -c 'import archmod.CHM; archmod.CHM.CHMDir("Docs").process_templates("Docs/Chm")'

%install
install -d \
    %{buildroot}/%{_prefix}/lib/%{name} \
    %{buildroot}/%{_datadir}/%{name} \
    %{buildroot}/%{_datadir}/%{name}/XSL \
    %{buildroot}/%{_datadir}/applications \
    %{buildroot}/%{_bindir} \
    %{buildroot}/%{_datadir}/mime/packages \
    %{buildroot}/%{_datadir}/icons/hicolor/512x512/apps \
    %{buildroot}/%{_datadir}/icons/hicolor/256x256/apps \
    %{buildroot}/%{_datadir}/icons/hicolor/128x128/apps \
    %{buildroot}/%{_datadir}/icons/hicolor/64x64/apps \
    %{buildroot}/%{_datadir}/icons/hicolor/48x48/apps \
    %{buildroot}/%{_datadir}/icons/hicolor/32x32/apps \
    %{buildroot}/%{_datadir}/icons/hicolor/16x16/apps \
    %{buildroot}/%{_mandir}/man1 \
    %{buildroot}/%{_docdir}/%{name} \
    %{buildroot}/%{_datadir}/appdata
install -p -m 0644 \
    Build/KeePass/Release/KeePass.exe \
    Ext/KeePass.config.xml \
    Ext/KeePass.exe.config \
    %{buildroot}/%{_prefix}/lib/%{name}
install -p -m 0644 \
    Ext/XSL/KDBX_Common.xsl Ext/XSL/KDBX_DetailsFull_HTML.xsl \
    Ext/XSL/KDBX_DetailsLight_HTML.xsl Ext/XSL/KDBX_PasswordsOnly_TXT.xsl \
    Ext/XSL/KDBX_Tabular_HTML.xsl \
    %{buildroot}/%{_datadir}/%{name}/XSL
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_512.png \
    %{buildroot}/%{_datadir}/icons/hicolor/512x512/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_256.png \
    %{buildroot}/%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_128.png \
    %{buildroot}/%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_64.png \
    %{buildroot}/%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_48.png \
    %{buildroot}/%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_32.png \
    %{buildroot}/%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -p -m 0644 -T Ext/Icons_15_VA/KeePass_Round/KeePass_Round_16.png \
    %{buildroot}/%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
desktop-file-install --dir=%{buildroot}/%{_datadir}/applications dist/%{name}.desktop
install -p -m 0644 dist/%{name}.xml %{buildroot}/%{_datadir}/mime/packages
install -p -m 0644 dist/%{name}.1 %{buildroot}/%{_mandir}/man1
install -p -m 0644 dist/%{name}.appdata.xml %{buildroot}/%{_datadir}/appdata
install -p dist/%{name} %{buildroot}/%{_bindir}

sed 's/\r$//' Docs/History.txt > %{buildroot}/%{_docdir}/%{name}/History.txt
sed 's/\r$//' Docs/License.txt > %{buildroot}/%{_docdir}/%{name}/License.txt
cp -pr Docs/Chm %{buildroot}/%{_docdir}/%{name}/

# translations
install -m 644 French.lngx  %{buildroot}%{_prefix}/lib/keepass

%files
%{_docdir}/%{name}
%{_bindir}/%{name}
%{_prefix}/lib/%{name}
%{_datadir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime
%{_datadir}/icons/hicolor/512x512/apps/%{name}.png
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
%{_mandir}/man1/%{name}.1*



%changelog
* Mon Feb 20 2017 guillomovitch <guillomovitch> 2.35-1.mga6
+ Revision: 1087043
- new version 2.35

* Mon Jul 04 2016 guillomovitch <guillomovitch> 2.34-1.mga6
+ Revision: 1038648
- new version 2.34

* Tue May 17 2016 guillomovitch <guillomovitch> 2.33-1.mga6
+ Revision: 1016566
- new version 2.33

* Wed Mar 23 2016 tv <tv> 2.32-1.mga6
+ Revision: 994283
- new release

* Wed Mar 23 2016 tv <tv> 2.31-2.mga6
+ Revision: 994274
- build fix
- use %%autosetup

* Tue Jan 12 2016 guillomovitch <guillomovitch> 2.31-1.mga6
+ Revision: 922222
- new version 2.31

* Thu Aug 20 2015 guillomovitch <guillomovitch> 2.30-1.mga6
+ Revision: 866989
- new version 2.30

* Tue Jun 23 2015 guillomovitch <guillomovitch> 2.29-1.mga6
+ Revision: 840333
- new version 2.29

* Fri May 22 2015 guillomovitch <guillomovitch> 2.28-3.mga5
+ Revision: 822601
- add french translation file (fix #13553)

* Mon May 18 2015 guillomovitch <guillomovitch> 2.28-2.mga5
+ Revision: 822333
- workaround libgdiplus linking issue by forcing a runtime dependency against the devel subpackage

* Mon Feb 09 2015 guillomovitch <guillomovitch> 2.28-1.mga5
+ Revision: 814448
- new version

* Wed Oct 15 2014 umeabot <umeabot> 2.27-3.mga5
+ Revision: 741750
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.27-2.mga5
+ Revision: 681031
- Mageia 5 Mass Rebuild

* Wed Jul 16 2014 guillomovitch <guillomovitch> 2.27-1.mga5
+ Revision: 653181
- new version 2.27

* Fri Jul 04 2014 guillomovitch <guillomovitch> 2.26-3.mga5
+ Revision: 643102
- add xdotool as runtime dependency, for web form support (#13552)

* Thu Jul 03 2014 guillomovitch <guillomovitch> 2.26-2.mga5
+ Revision: 642755
- fix webdav storage, using debian patch

* Fri May 23 2014 tv <tv> 2.26-1.mga5
+ Revision: 625186
- new release
- new release

* Fri May 23 2014 tv <tv> 2.25-2.mga5
+ Revision: 625115
- rebuild with latest mono in order to try make it work

* Mon Feb 24 2014 guillomovitch <guillomovitch> 2.25-1.mga5
+ Revision: 596606
- new version 2.25

* Fri Feb 21 2014 guillomovitch <guillomovitch> 2.24-1.mga5
+ Revision: 595260
- imported package keepass

